pub(crate) struct KeyScheduleClientBeforeFinished(KeyScheduleBeforeFinished);Expand description
Client-side key schedule before the finished message is sent.
This differs from KeyScheduleTrafficWithClientFinishedPending because
none of the final traffic secrets are installed yet. After the finished
message is sent, into_traffic() does that.
Tuple Fields
0: KeyScheduleBeforeFinishedImplementations
Sourceimpl KeyScheduleClientBeforeFinished
impl KeyScheduleClientBeforeFinished
pub(crate) fn into_traffic( self, common: &mut CommonState, hs_hash: Output, ) -> (KeyScheduleTraffic, KeyScheduleResumption)