pub(crate) struct KeyScheduleTrafficWithClientFinishedPending {
handshake_client_traffic_secret: OkmBlock,
before_finished: KeyScheduleBeforeFinished,
}Expand description
KeySchedule during traffic stage, retaining the ability to calculate the client’s finished verify_data. The traffic stage key schedule can be extracted from it through signing the client finished hash.
Fields
handshake_client_traffic_secret: OkmBlockbefore_finished: KeyScheduleBeforeFinishedImplementations
Sourceimpl KeyScheduleTrafficWithClientFinishedPending
impl KeyScheduleTrafficWithClientFinishedPending
pub(crate) fn update_decrypter(&self, common: &mut CommonState)
pub(crate) fn sign_client_finish( self, hs_hash: &Output, common: &mut CommonState, ) -> (KeyScheduleBeforeFinished, Tag)